class Log {
    constructor() {
        this.levels = {
            debug: 'debug',
            info: 'info',
            error: 'error',
            warning: 'warning',
        };
        this.isDebugMessagesVisible = (process.env.ENV != 'production');
    }

    /**
     * @return {string}
     */
    static getTime() {
        let date = new Date();

        return date.toLocaleString();
    }

    /**
     * @param {string} title
     * @param {*} loggedObject
     * @param {string} level
     */
    log(title, loggedObject, level) {
        if (!this.levels[level]) {
            level = this.levels.info;
        }
        console.log(
            Log.getTime() + ' / ' + level + ': ' + title + ' - ',
            loggedObject
        );
    }

    /**
     * @param {string} title
     * @param {*=} loggedObject
     */
    debug(title, loggedObject) {
        if (!this.isDebugMessagesVisible) {
            return;
        }
        this.log(title, loggedObject, this.levels.debug);
    }

    /**
     * @param {string} title
     * @param {*=} loggedObject
     */
    info(title, loggedObject) {
        this.log(title, loggedObject, this.levels.info);
    }

    /**
     * @param {string} title
     * @param {*=} loggedObject
     */
    warning(title, loggedObject) {
        this.log(title, loggedObject, this.levels.warning);
    }

    /**
     * @param {string} title
     * @param {*=} loggedObject
     */
    error(title, loggedObject) {
        this.log(title, loggedObject, this.levels.error);
    }
}

module.exports = new Log();
